@@ -51,12 +51,6 @@ def main(args=sys.argv[1:]):
                       help='Write JUnit XML to this file. Defaults to '
                       'lettucetests.xml')
 
-    parser.add_option("--tags",
-                      action="append",
-                      dest="tags_to_run",
-                      default=[],
-                      help='Comma separated list of tags, run if any found, multiple uses of this argument mean logical AND')
-
     options, args = parser.parse_args()
     if args:
         base_path = os.path.abspath(args[0])
@@ -66,15 +60,13 @@ def main(args=sys.argv[1:]):
     except ValueError:
         pass
 
-    run_controller = lettuce.RunController()
-    tag_checker = lettuce.core.TagChecker(options.tags_to_run)
-    run_controller.add(tag_checker)
-
-    runner = lettuce.Runner(base_path, scenarios=options.scenarios,
-                            verbosity=options.verbosity,
-                            enable_xunit=options.enable_xunit,
-                            xunit_filename=options.xunit_file,
-                            run_controller=run_controller)
+    runner = lettuce.Runner(
+        base_path,
+        scenarios=options.scenarios,
+        verbosity=options.verbosity,
+        enable_xunit=options.enable_xunit,
+        xunit_filename=options.xunit_file,
+    )
 
     result = runner.run()
     if not result or result.steps != result.steps_passed:
