@@ -32,7 +32,8 @@ def get_stripped_lines(string, ignore_lines_starting_with=''):
     string = unicode(string)
     lines = [unicode(l.strip()) for l in string.splitlines()]
     if ignore_lines_starting_with:
-        filter_func = lambda x: x and not x.startswith(ignore_lines_starting_with)
+        filter_func = lambda x: x and not x.startswith(
+            ignore_lines_starting_with)
     else:
         filter_func = lambda x: x
 
@@ -174,77 +175,3 @@ def parse_multiline(lines):
                 line = line[:-1]
             multilines.append(line)
     return u'\n'.join(multilines)
-
-
-def extract_tags_from_line(given_line):
-    """returns tags_array if given_line contains tags, else None"""
-    line = given_line.rstrip()
-    tags = []
-    if re.match("\s*?\@", line):
-        tags = [tag for tag in re.split("\s*\@", line) if len(tag) > 0]
-    if len(tags) == 0 or any(' ' in tag for tag in tags):
-        return None
-    return tags
-
-
-def consume_tags_lines(lines, tags):
-    """consumes lines from start of given set of lines and
-       populates tags array,
-       stops when run out of lines that are tag lines"""
-    while True:
-        line = lines[0]
-        tags_on_lines = extract_tags_from_line(line)
-        if tags_on_lines:
-            tags.extend(tags_on_lines)
-            lines.pop(0)
-        else:
-            break
-
-
-def consume_scenario(lines, scenario_prefix):
-    """return string of scenario text
-       and reduce lines array by that much"""
-    sep = unicode(scenario_prefix)
-    regex = re.compile(escape_if_necessary(sep),  re.UNICODE | re.M | re.I)
-    scenario_lines = []
-    # Optional first lines are tags, is part of the scenario
-    while len(lines) > 0:
-        if extract_tags_from_line(lines[0]):
-            scenario_lines.append(lines.pop(0))
-        break
-    # First line must be scenario_prefix
-    if regex.match(lines[0]):
-        scenario_lines.append(lines.pop(0))
-    else:
-        raise AssertionError("expecting scenario, at line [" + str(lines[0]) + "]")
-
-    scenario_lines.extend(get_lines_till_next_scenario(lines, scenario_prefix))
-    return unicode("\n".join(scenario_lines))
-
-
-def get_lines_till_next_scenario(lines, scenario_prefix):
-    """returns array of lines up till next scenario block"""
-    sep = unicode(scenario_prefix)
-    regex = re.compile(escape_if_necessary(sep),  re.UNICODE | re.M | re.I)
-    scenario_lines = []
-    in_multi_line_string = False
-    # Scan till hit tags line or (next) scenario_prefix
-    while len(lines) > 0:
-        line = lines[0]
-        if "\"\"\"" in line:
-            in_multi_line_string = not in_multi_line_string
-        if not in_multi_line_string:
-            if regex.match(line) or extract_tags_from_line(line):
-                break
-        scenario_lines.append(lines.pop(0))
-    return scenario_lines
-
-
-def split_scenarios(lines, scenario_prefix):
-    """returns array of strings, one per scenario"""
-    scenario_strings = []
-    while len(lines) > 0:
-        scenario_string = consume_scenario(lines, scenario_prefix)
-        if scenario_string:
-            scenario_strings.append(scenario_string)
-    return scenario_strings
